@@ -6,8 +6,7 @@
 
 import inspect
 import sys
-from .options import Options
-from .types import TypesActions, Types
+from .types import TypesActions
 from .loggs import Loggs
 
 logs = Loggs('Core')
@@ -44,7 +43,7 @@ def validParam(fn):
     """
     if len(inspect.getargspec(fn)[0]) < 4:
         logs.error(
-            'Lo metodos GET, DELETE, UPDATE requieren 3 parametros (data, auth, id) ')
+            'Lo metodos GET, DELETE, UPDATE requieren 3 parametros')
         sys.exit(-1)
 
 
